SubscriptionState

Enum SubscriptionState 

pub enum SubscriptionState {
    Bound,
    Joined,
}
Represents the lifecycle state of a subscription.

A subscription is always associated with a bound socket, but may or may not currently be joined to a multicast group.

Variants



Bound

Socket is bound but multicast group is not joined.



Joined

Multicast group is joined.